@@ -30,7 +30,6 @@
 #include <QLineEdit>
 #include <QComboBox>
 #include <QSlider>
-#include <QButtonGroup>
 #include <QTabWidget>
 #include <QFrame>
 #include <QVBoxLayout>
@@ -51,7 +50,7 @@ KameraConfigDialog::KameraConfigDialog(Camera */*camera*/,
     m_widgetRoot(widget)
 {
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
-            QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+            QDialogButtonBox::Ok|QDialogButtonBox::Cancel, this);
 
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -63,8 +62,8 @@ KameraConfigDialog::KameraConfigDialog(Camera */*camera*/,
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
 
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &KameraConfigDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &KameraConfigDialog::reject);
     okButton->setDefault(true);
     setModal( true );
 
@@ -79,7 +78,7 @@ KameraConfigDialog::KameraConfigDialog(Camera */*camera*/,
 
     appendWidget(main, widget);
 
-    connect(okButton,SIGNAL(clicked()),this,SLOT(slotOk()));
+    connect(okButton, &QPushButton::clicked, this,  &KameraConfigDialog::slotOk);
     mainLayout->addWidget(buttonBox);
 }
 
